
clear
insheet using simultaneous_4PL.csv, comma names
drop v1
recode rep (3=24) (6=48) (12=96)
gen fourpl = 1
save result_4PL.dta, replace

clear
insheet using simultaneous_dunnett.csv, comma names
drop v1
gen fourpl = 0
save result_dunnett.dta, replace

clear
use result_4PL.dta
append using result_dunnett.dta
label define fourpl_label 1 "4PL" 0 "Dunnett"
label values fourpl fourpl_label
gen l1 = real(line1)
gen l2 = real(line2)
gen l3 = real(line3)
gen l4 = real(line4)
gen l5 = real(line5)
drop line1-line5
clonevar line1 = l1
clonevar line2 = l2
clonevar line3 = l3
clonevar line4 = l4
clonevar line5 = l5
drop l1-l5
sort fourpl slope lower upper ed50 error rep
save result_combined.dta, replace


clear
use result_combined.dta

// power for pilot stage
table error fourpl, c(mean flag)

// generate indicators for significance
gen alpha = cond(flag==1, cond(line5<0.05,1,0),0)
gen l1power = cond(flag==1,cond(line1<0.05,1,0),0)
gen l2power = cond(flag==1,cond(line2<0.05,1,0),0)
gen l3power = cond(flag==1,cond(line3<0.05,1,0),0)
gen l4power = cond(flag==1,cond(line4<0.05,1,0),0)

// control of alpha
table fourpl if flag == 1, c(mean alpha)

// collapse to power summary statistics by condition
collapse (mean) flag l1power-l4power, ///
	by(slope lower upper ed50 error rep fourpl)
	
	
/* export .csv file for R boxplots */

outsheet using result_combined_power.csv, comma names replace

/* tables of means */
foreach var of varlist slope lower upper ed50 {
if "`var'" == "slope" local myvar l1power
if "`var'" == "lower" local myvar l2power
if "`var'" == "upper" local myvar l3power
if "`var'" == "ed50" local myvar l4power
table error fourpl rep, by(`var') ///
	c(mean `myvar') format(%9.2f)
}


/* stripplots show variance differences */
egen group = group(error rep), label
local i 1
foreach var of varlist slope lower upper ed50 {
	if "`var'" == "slope" local myvar l1power
	if "`var'" == "lower" local myvar l2power
	if "`var'" == "upper" local myvar l3power
	if "`var'" == "ed50" local myvar l4power
	levelsof `var', local(`var'_levels)
	foreach lp of local `var'_levels {
		display "`var'", "`myvar'", "`lp'"
		stripplot `myvar' if `var'==`lp', box ///
			over(fourpl) ///
			by(group, compact col(1) note("")) ///
			msize(medium) mlw(thin) mlc(gs8) jitter(1) ///
			ytitle("") xlabel(0(.2)1) ///
			subtitle(, pos(9) ring(1) nobexpand bcolor(none) placement(e)) ///
			xtitle("Power for `var' = `lp'")
		more
		local i = `i' + 1
	}
}


/* mean and median dotplots */

// slope

graph dot (mean) l1power, over(fourpl) over(rep) over(error) ///
	ylabel(0(.2)1) name(line1, replace) ///
	by(slope, total legend(at(6) pos(0)))

graph dot (p50) l1power, over(fourpl) over(rep) over(error) ///
	ylabel(0(.2)1) name(line1, replace) ///
	by(slope, total legend(at(6) pos(0)))	

graph dot (p50) l1power, over(fourpl) over(error) ///
	ylabel(0(.2)1) name(line1, replace) ///
	by(slope, total legend(at(6) pos(0)))
	
graph dot (p50) l1power, over(fourpl) over(rep) ///
	ylabel(0(.2)1) name(line1, replace) ///
	by(slope, total legend(at(6) pos(0)))

// lower
	
graph dot (mean) l2power, over(fourpl) over(rep) over(error) ///
	ylabel(0(.2)1) name(line2, replace) ///
	by(lower, total legend(at(6) pos(0)))	
	
graph dot (p50) l2power, over(fourpl) over(rep) over(error) ///
	ylabel(0(.2)1) name(line2, replace) ///
	by(lower, total legend(at(6) pos(0)))	
	
graph dot (p50) l2power, over(fourpl) over(error) ///
	ylabel(0(.2)1) name(line2, replace) ///
	by(lower, total legend(at(6) pos(0)))	

graph dot (p50) l2power, over(fourpl) over(rep) ///
	ylabel(0(.2)1) name(line2, replace) ///
	by(lower, total legend(at(6) pos(0)))	

// upper
	
graph dot (mean) l3power, over(fourpl) over(rep) over(error) ///
	ylabel(0(.2)1) name(line3, replace) ///
	by(upper, total legend(at(6) pos(0)))	

graph dot (p50) l3power, over(fourpl) over(rep) over(error) ///
	ylabel(0(.2)1) name(line3, replace) ///
	by(upper, total legend(at(6) pos(0)))

graph dot (p50) l3power, over(fourpl) over(error) ///
	ylabel(0(.2)1) name(line3, replace) ///
	by(upper, total legend(at(6) pos(0)))	
	
graph dot (p50) l3power, over(fourpl) over(rep) ///
	ylabel(0(.2)1) name(line3, replace) ///
	by(upper, total legend(at(6) pos(0)))	

// ed50

graph dot (mean) l4power, over(fourpl) over(rep) over(error) ///
	ylabel(0(.2)1) name(line4, replace) ///
	by(ed50, total legend(at(6) pos(0)))	

graph dot (p50) l4power, over(fourpl) over(rep) over(error) ///
	ylabel(0(.2)1) name(line4, replace) ///
	by(ed50, total legend(at(6) pos(0)))

graph dot (p50) l4power, over(fourpl) over(error) ///
	ylabel(0(.2)1) name(line4, replace) ///
	by(ed50, total legend(at(6) pos(0)))	
	
graph dot (p50) l4power, over(fourpl) over(rep) ///
	ylabel(0(.2)1) name(line4, replace) ///
	by(ed50, total legend(at(6) pos(0)))




/* statistics for power; do not over interpret these */


bysort slope error rep: egen rank_l1power = rank(l1power)
bysort lower error rep: egen rank_l2power = rank(l2power)
bysort upper error rep: egen rank_l3power = rank(l3power)
bysort ed50 error rep: egen rank_l4power = rank(l4power)

tempname memhold
tempfile results
postfile `memhold' str10 var lp le lr p mu_dunnett mu_4PL using `results'

levelsof error, local(error_levels)
levelsof rep, local(rep_levels)

foreach var of varlist slope lower upper ed50 {
levelsof `var', local(`var'_levels)
if "`var'" == "slope" local myvar rank_l1power
if "`var'" == "lower" local myvar rank_l2power
if "`var'" == "upper" local myvar rank_l3power
if "`var'" == "ed50" local myvar rank_l4power

foreach lp of local `var'_levels {
	foreach le of local error_levels {
		foreach lr of local rep_levels {
			display "-> `var':"`lp', "error:"`le', "rep:"`lr'
			display "------------------------------"
			quietly ttest `myvar' ///
				if `var'==`lp' & error==`le' & rep==`lr', by(fourpl) welch
			if r(p) < 0.05/96 {
				display "t-test significant"
				display "t-test rank mean:", %4.2f r(mu_1), ///
					"4PL rank mean:", %4.2f r(mu_2)
				}
				else {
				display "t-test NS"
				}
			post `memhold' ("`var'") (`lp') (`le') (`lr') (r(p)) (r(mu_1)) (r(mu_2))
			quietly sdtest `myvar' ///
				if `var'==`lp' & error==`le' & rep==`lr', by(fourpl)
			if r(p) < 0.05/96 {
				display "sdtest significant"
				}
				else {
				display "sdtest NS"
				}
				display _newline
		}
	}
}

}

postclose `memhold'
use "`results'", clear
gen adjp = p*96
gen sig = adjp < .05
tab var sig if mu_4PL > mu_dunnett
tab var sig if mu_dunnett > mu_4PL


