
mysim <- function(from, to) {
	
set.seed(to)

###
### simulation with 4PL in pilot data and CSS data
###

dose.levels = c(0.25, 0.5, 1, 2, 4, 8, 16, 32)

#set up matrix to hold final p-values
#9600 because 2 errors * 3 sample sizes * 256 parameter rows * 100 simulations / 16 cpu cores = 9600 
final.result.4PL = matrix(,9600, 12)
colnames(final.result.4PL) = c("slope", "lower", "upper", "ed50", "error", "rep", "flag", "line1", "line2", "line3", "line4", "line5")
myindex = 1


# set up parameters matrix
mymatrix = matrix(,256,4)
i = 1
for (slope in c(-1, -0.5, 0.5, 1)) {
	for (bottom in c(-10, -5, 5, 10)) {
		for (top in c(-20, -10, 10, 20)) {
			for (ed50 in c(-1, -0.5, 0.5, 1)) {
				mymatrix[i,] = c(slope, bottom, top, ed50)
				i = i + 1
			}

		}
	}
}


# loop across rows in parameters matrix
for (prow in from:to) {

	# set lines to parameters from one row
	# line = c(slope, lower, upper, ed50)
	p1 = c(-3, 100, 200, 3)
	l1 = c(mymatrix[prow,1], 0, 0, 0)
	l2 = c(0, mymatrix[prow,2], 0, 0)
	l3 = c(0, 0, mymatrix[prow,3], 0)
	l4 = c(0, 0, 0, mymatrix[prow,4])
	l5 = c(0, 0, 0, 0)
	p2 = p1 + l1 + l2 + l3 + l4 + l5


for(error in c(5,10)) {
	for(rep in c(3, 6, 12)) {
		for(i in 1:100) {
			parents8 = parents8doses(dose.levels, replicate=3, error, p1, p2, l1, l2, l3, l4, l5)
			flag = parents.4pl(parents8)
			mydata = myfpl.data(dose.levels, rep, error, p1, p2, l1, l2, l3, l4, l5)
			mydata.long = wide.to.long(mydata)
			mypvalues = all.css.fpl(mydata.long)
			if (flag==1) {
				final.result.4PL[myindex,] = c(mymatrix[prow, 1], mymatrix[prow, 2], mymatrix[prow, 3], mymatrix[prow, 4], error, rep, flag, mypvalues[1], mypvalues[2], mypvalues[3], mypvalues[4], mypvalues[5]) } else {
				final.result.4PL[myindex,] = c(mymatrix[prow, 1], mymatrix[prow, 2], mymatrix[prow, 3], mymatrix[prow, 4], error, rep, flag, NA, NA, NA, NA, NA)
			}
			#print(i)
			#print(myindex)
			myindex = myindex + 1
		}	
	}
}

} #end prow loop



###
### using ANOVA and t-tests (8 doses in parents)
###

dose.levels = c(0.25, 0.5, 1, 2, 4, 8, 16, 32)

#set up matrix to hold final pvalues data
#9600 because 2 errors * 3 sample sizes * 256 parameter rows * 100 simulations / 16 cpu cores = 9600 
final.result.dunnett = matrix(,9600, 13)
colnames(final.result.dunnett) = c("slope", "lower", "upper", "ed50", "error", "rep", "flag", "dose", "line1", "line2", "line3", "line4", "line5") #note extra dose column
myindex = 1


# set up parameters matrix
mymatrix = matrix(,256,4)
i = 1
for (slope in c(-1, -0.5, 0.5, 1)) {
	for (bottom in c(-10, -5, 5, 10)) {
		for (top in c(-20, -10, 10, 20)) {
			for (ed50 in c(-1, -0.5, 0.5, 1)) {
				mymatrix[i,] = c(slope, bottom, top, ed50)
				i = i + 1
			}

		}
	}
}

# loop across rows in parameters matrix
for (prow in from:to) {

	# set lines to parameters from one row
	# line = c(slope, lower, upper, ed50)
	p1 = c(-3, 100, 200, 3)
	l1 = c(mymatrix[prow,1], 0, 0, 0)
	l2 = c(0, mymatrix[prow,2], 0, 0)
	l3 = c(0, 0, mymatrix[prow,3], 0)
	l4 = c(0, 0, 0, mymatrix[prow,4])
	l5 = c(0, 0, 0, 0)
	p2 = p1 + l1 + l2 + l3 + l4 + l5
	

for(error in c(5,10)) {
	for(rep in c(24, 48, 96)) {
		for(i in 1:100) {
			parents8 = parents8doses(dose.levels, replicate=3, error, p1, p2, l1, l2, l3, l4, l5)
			flag = interaction.test(parents8)
			dose.level = sme.test(dose.levels, parents8)
			mydata = myfpl.data(dose.levels, rep, error, p1, p2, l1, l2, l3, l4, l5)
			mydata.long = wide.to.long(mydata)
			mypvalues = dunnett.test(mydata.long, dose.level)
			if (flag==1) {
				final.result.dunnett[myindex,] = c(mymatrix[prow, 1], mymatrix[prow, 2], mymatrix[prow, 3], mymatrix[prow, 4], error, rep, flag, dose.level, mypvalues[1], mypvalues[2], mypvalues[3], mypvalues[4], mypvalues[5]) } else {
				final.result.dunnett[myindex,] = c(mymatrix[prow, 1], mymatrix[prow, 2], mymatrix[prow, 3], mymatrix[prow, 4], error, rep, flag, dose.level, NA, NA, NA, NA, NA) 
			}
			#print(i)
			#print(myindex)
			myindex = myindex + 1
		}	
	}
}

} #end prow loop

myfilename = paste("myresults_", from, "_to_", to, ".RData", sep="")
save(final.result.4PL, final.result.dunnett, file= myfilename)

}
